TsnetFfi class

FFI-based implementation for Android and Linux. Loads the Go shared library and calls C functions directly.

Constructors

TsnetFfi()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start(String stateDir, String authKey, String hostname) Future<void>
startProxy(String remoteIP, int remotePort) Future<int>
status() Future<String?>
stop() Future<void>
stopProxy() Future<void>
tailscaleIP() Future<String>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited